==> rest-sdk-java-generator-0.1.5-sources.jar: com/mulesoft/connectivity/rest/sdk/templating/sdk/metadata/SdkTriggerOutputMetadataResolver.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.templating.sdk.metadata;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorOperation;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.type.TypeDefinition;
import com.mulesoft.connectivity.rest.sdk.templating.api.RestSdkRunConfiguration;
import com.mulesoft.connectivity.rest.sdk.templating.exception.TemplatingException;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.SdkConnector;

import java.nio.file.Path;

public class SdkTriggerOutputMetadataResolver extends SdkOutputMetadataResolver {

  public SdkTriggerOutputMetadataResolver(Path outputDir,
                                          ConnectorModel connectorModel,
                                          SdkConnector sdkConnector,
                                          ConnectorOperation operation,
                                          TypeDefinition typeDefinition,
                                          String triggerName,
                                          RestSdkRunConfiguration runConfiguration)
      throws TemplatingException {
    super(outputDir, connectorModel, sdkConnector, operation, typeDefinition, triggerName, runConfiguration);
  }

  @Override
  protected String getClassNameSuffix() {
    return "Trigger" + super.getClassNameSuffix();
  }
}

==> rest-sdk-java-generator-0.6.0-sources.jar: com/mulesoft/connectivity/rest/sdk/templating/sdk/metadata/SdkTriggerOutputMetadataResolver.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.templating.sdk.metadata;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorModel;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorOperation;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.type.TypeDefinition;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.type.schema.TypeSchema;
import com.mulesoft.connectivity.rest.sdk.templating.api.RestSdkRunConfiguration;
import com.mulesoft.connectivity.rest.sdk.templating.exception.TemplatingException;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.SdkConnector;
import com.mulesoft.connectivity.rest.sdk.templating.sdk.util.FileGenerationUtil;

import java.nio.file.Path;

public class SdkTriggerOutputMetadataResolver extends SdkOutputMetadataResolver {

  public SdkTriggerOutputMetadataResolver(Path outputDir,
                                          ConnectorModel connectorModel,
                                          SdkConnector sdkConnector,
                                          ConnectorOperation operation,
                                          TypeDefinition typeDefinition,
                                          String triggerName,
                                          RestSdkRunConfiguration runConfiguration)
      throws TemplatingException {
    super(outputDir, connectorModel, sdkConnector, operation, typeDefinition, triggerName, runConfiguration);
  }

  @Override
  protected String getSchemaName(ConnectorOperation operation, FileGenerationUtil.SchemaNameType schemaNameType,
                                 TypeSchema source, String partName) {
    return "trigger-" + super.getSchemaName(operation, schemaNameType, source, partName);
  }

  @Override
  protected String getClassNameSuffix() {
    return "Trigger" + super.getClassNameSuffix();
  }
}
